#ifndef COLORER_COMMONSTRING_H
#define COLORER_COMMONSTRING_H

/// default unicode char definition

typedef char16_t UChar;
typedef wchar_t wchar;
typedef char16_t w2char;
typedef char32_t w4char;
typedef unsigned char byte;

constexpr UChar BAD_WCHAR = 0xFFFF;

#endif // COLORER_COMMONSTRING_H


